<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>PluginItem</name>
    <message>
        <location filename="../pluginitem.cpp" line="89"/>
        <source>Remove from dock</source>
        <translation>Aus dem Dock entfernen</translation>
    </message>
</context>
<context>
    <name>QuickPluginItem</name>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Remove from dock</source>
        <translation>Aus dem Dock entfernen</translation>
    </message>
    <message>
        <location filename="../quickpluginitem.cpp" line="160"/>
        <source>Pin to dock</source>
        <translation>Ans Dock anpinnen</translation>
    </message>
</context>
</TS>